#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2014 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.Common;
using HeuristicLab.Core.Views;
using HeuristicLab.MainForm;
using System;
using System.Windows.Forms;

namespace HeuristicLab.Optimization.Networks.Views {
  [View("ValuePort View")]
  [Content(typeof(ValuePort<>), true)]
  [Content(typeof(IValuePort<>), false)]
  [Content(typeof(IValuePort), false)]
  public partial class ValuePortView : PortView {
    public new IValuePort Content {
      get { return (IValuePort)base.Content; }
      set { base.Content = value; }
    }

    public ValuePortView() {
      InitializeComponent();
    }

    protected override void DeregisterContentEvents() {
      Content.ValueChanged -= Content_ValueChanged;
      base.DeregisterContentEvents();
    }

    protected override void RegisterContentEvents() {
      base.RegisterContentEvents();
      Content.ValueChanged += Content_ValueChanged;
    }

    protected override void OnContentChanged() {
      base.OnContentChanged();
      if (Content == null) {
        valueViewHost.Content = null;
      } else {
        valueViewHost.ViewType = null;
        valueViewHost.Content = Content.Value as IContent;
      }
    }

    protected override void SetEnabledStateOfControls() {
      base.SetEnabledStateOfControls();
      valueGroupBox.Enabled = (Content as IContent) != null;
    }
    protected virtual void Content_ValueChanged(object sender, System.EventArgs e) {
      if (InvokeRequired)
        Invoke(new EventHandler(Content_ValueChanged), sender, e);
      else {
        valueViewHost.ViewType = null;
        valueViewHost.Content = Content.Value as IContent;
      }
    }
  }
}
